/// <reference types="vscode/src/vscode-dts/vscode" />
/// <reference types="vscode/src/vscode-dts/vscode.proposed.createFileSystemWatcher" />
/// <reference types="vscode/src/vscode-dts/vscode.proposed.codeActionAI" />
/// <reference types="vscode/src/vscode-dts/vscode.proposed.codeActionRanges" />
/// <reference types="vscode/src/vscode-dts/vscode.proposed.mappedEditsProvider" />
/// <reference types="vscode/src/vscode-dts/vscode.proposed.multiDocumentHighlightProvider" />
/// <reference types="vscode/src/vscode-dts/vscode.proposed.workspaceTrust" />
import * as vscode from 'vscode';
/**
 * Maps of file resources
 *
 * Attempts to handle correct mapping on both case sensitive and case in-sensitive
 * file systems.
 */
export declare class ResourceMap<T> {
    protected readonly _normalizePath: (resource: vscode.Uri) => string | undefined;
    protected readonly config: {
        readonly onCaseInsensitiveFileSystem: boolean;
    };
    private static readonly defaultPathNormalizer;
    private readonly _map;
    constructor(_normalizePath: (resource: vscode.Uri) => string | undefined, config: {
        readonly onCaseInsensitiveFileSystem: boolean;
    });
    get size(): number;
    has(resource: vscode.Uri): boolean;
    get(resource: vscode.Uri): T | undefined;
    set(resource: vscode.Uri, value: T): void;
    delete(resource: vscode.Uri): void;
    clear(): void;
    values(): Iterable<T>;
    entries(): Iterable<{
        resource: vscode.Uri;
        value: T;
    }>;
    private toKey;
    private isCaseInsensitivePath;
}
//# sourceMappingURL=resourceMap.d.ts.map